"use strict";

/* exported logger */

var AbstractGuiElement = require('../AbstractGuiElement');
var GuiConnector = require('../../GuiConnector');

var Functions = require('../../functions');
var logger = require('../../logger');

var guiUtils = new (require('../leftPanel/GuiUtils'))();

function EditProjectDialog(params) {
  AbstractGuiElement.call(this, params);
  var self = this;

  self.createGui();
}

EditProjectDialog.prototype = Object.create(AbstractGuiElement.prototype);
EditProjectDialog.prototype.constructor = EditProjectDialog;

EditProjectDialog.prototype.createGui = function() {
  var self = this;
  var element = self.getElement();
  var project = self.getProject();

  var tabDiv = Functions.createElement({
    type : "div",
    name : "tabView",
    className : "tabbable boxed parentTabs"
  });
  element.appendChild(tabDiv);

  var tabMenuDiv = Functions.createElement({
    type : "ul",
    className : "nav nav-tabs"
  });
  tabDiv.appendChild(tabMenuDiv);

  var tabContentDiv = Functions.createElement({
    type : "div",
    className : "tab-content"
  });
  tabDiv.appendChild(tabContentDiv);

  self.createGeneralTab(tabMenuDiv, tabContentDiv);
  self.createOverlaysTab(tabMenuDiv, tabContentDiv);
  self.createUsersTab(tabMenuDiv, tabContentDiv);
};

EditProjectDialog.prototype.createGeneralTab = function(tabMenuDiv, tabContentDiv) {
  var self = this;
  self.addTab({
    tabMenuDiv : tabMenuDiv,
    tabContentDiv : tabContentDiv,
    name : "GENERAL",
    id : self.getProject().getProjectId() + "_general_tab",
    content : self.createGeneralTabContent(),
  });

};

EditProjectDialog.prototype.addTab = function(params) {
  var self = this;
  var navLi = guiUtils.createTabMenuObject({
    id : params.id,
    name : params.name,
    navigationBar : params.tabMenuDiv
  });
  params.tabMenuDiv.appendChild(navLi);

  var contentDiv = guiUtils.createTabContentObject({
    id : params.id,
    navigationObject : navLi,
    navigationBar : params.tabMenuDiv
  });

  params.tabContentDiv.appendChild(contentDiv);
};

EditProjectDialog.prototype.createGeneralTabContent = function() {

};

EditProjectDialog.prototype.createOverlaysTab = function(tabMenuDiv, tabContentDiv) {
  var self = this;
  self.addTab({
    tabMenuDiv : tabMenuDiv,
    tabContentDiv : tabContentDiv,
    name : "OVERLAYS",
    id : self.getProject().getProjectId() + "_overlays_tab",
    content : self.createOverlaysTabContent(),
  });
};

EditProjectDialog.prototype.createOverlaysTabContent = function() {

};

EditProjectDialog.prototype.createUsersTab = function(tabMenuDiv, tabContentDiv) {
  var self = this;
  self.addTab({
    tabMenuDiv : tabMenuDiv,
    tabContentDiv : tabContentDiv,
    name : "USERS",
    id : self.getProject().getProjectId() + "_users_tab",
    content : self.createUsersTabContent(),
  });
};

EditProjectDialog.prototype.createUsersTabContent = function() {

};

EditProjectDialog.prototype.init = function() {
};

EditProjectDialog.prototype.destroy = function() {
  $(this.getElement()).dialog("destroy");
};

EditProjectDialog.prototype.open = function() {
  var self = this;
  var div = self.getElement();
  if (!$(div).hasClass("ui-dialog-content")) {
    $(div).dialog({
      title : self.getProject().getProjectId(),
      width : 400,
    });
  }
  $(div).dialog("open");
};

module.exports = EditProjectDialog;
